@@ -1,11 +1,14 @@
 """ Module that scrapes a web page for hyperlinks """
 import re
 import requests
+import collections
+import pprint
+
 from bs4 import BeautifulSoup
 
 class Links(object):
     """Grabs links from a web page
-    based upon a URL, filters, and limits"""
+    based upon a URL and filters"""
     def __init__(self, href=None, text=None):
         """ Create instance of Links class
 
@@ -28,15 +31,20 @@ class Links(object):
     def __repr__(self):
         return "<Links {0}>".format(self._href or self._text[:15] + '...')
 
-    def find(self, limit=None,
-            reverse=False, sort=None, exclude=None, **filters):
+    def find(self, limit=None, reverse=False, sort=None,
+            exclude=None, duplicates=True, pretty=False, **filters):
         """ Using filters and sorts, this finds all hyperlinks
-        on a web page 
+        on a web page
 
-        :param limit: Crop results down to limit specified 
-        :param reverse: Reverse the list of links, useful for before limiting 
-        :param exclude: Remove links from list 
+        :param limit: Crop results down to limit specified
+        :param reverse: Reverse the list of links, useful for before limiting
+        :param exclude: Remove links from list
+        :param duplicates: Determines if identical URLs should be displayed
+        :param pretty: Quick and pretty formatting using pprint
         :param filters: All the links to search for """
+        if exclude is None:
+            exclude = []
+
         if filters is None:
             filters = {}
         search = self._soup.findAll('a', **filters)
@@ -57,23 +65,45 @@ class Links(object):
             except KeyError:
                 pass
 
-            links.append(build_link)
+            ignore_link = False
+            for nixd in exclude:
+                for key, value in iteritems(nixd):
+                    if key in build_link:
+                        if isinstance(build_link[key], collections.Iterable):
+                            for item in build_link[key]:
+                                ignore_link = exclude_match(value, item)
+                        else:
+                            ignore_link = exclude_match(value, build_link[key])
+
+            if not duplicates:
+                for link in links:
+                    if link['href'] == anchor['href']:
+                        ignore_link = True
+
+            if not ignore_link:
+                links.append(build_link)
 
             if limit is not None and len(links) == limit:
                 break
 
-        if exclude:
-            pop_elem = []
-            for key, value in exclude.iteritems():
-                for item in links:
-                    if key in item and (value == item[key] or value.search(item[key])):
-                        links.remove(item)
-
         if sort is not None:
             links = sorted(links, key=sort, reverse=reverse)
 
-        return links
+        if pretty:
+            pp = pprint.PrettyPrinter(indent=4)
+            return pp.pprint(links)
+        else:
+            return links
 
+def exclude_match(exclude, link_value):
+    """ Check excluded value against the link's current value """
+    if hasattr(exclude, "search") and exclude.search(link_value):
+        return True
+
+    if exclude == link_value:
+        return True
+
+    return False
 
 def seoify_hyperlink(hyperlink):
     """Modify a hyperlink to make it SEO-friendly by replacing
@@ -82,3 +112,11 @@ def seoify_hyperlink(hyperlink):
     :param hyperlink: URL to attempt to grab SEO from """
     last_slash = hyperlink.rfind('/')
     return re.sub(r' +|-', ' ', hyperlink[last_slash+1:])
+
+def iteritems(d):
+    """ Factor-out Py2-to-3 differences in dictionary item
+    iterator methods """
+    try:
+         return d.iteritems()
+    except AttributeError:
+         return d.items()
\ No newline at end of file
