@@ -1,5 +1,8 @@
 """ Unit test Links functionality"""
+import os.path
 import unittest
+import re
+
 import requests
 import vcr
 import bs4
@@ -7,6 +10,8 @@ import bs4
 from linkGrabber import Links
 from linkGrabber.tests import test_data as td
 
+BASE_DIR = os.path.dirname(os.path.realpath(__file__))
+
 class TestScrape(unittest.TestCase):
     """ A set of unit tests for Links """
     def setUp(self):
@@ -14,10 +19,10 @@ class TestScrape(unittest.TestCase):
         self.url = "http://www.google.com"
         self.bad_url = "www.google.com"
         # grab some example html pages to test
-        with vcr.use_cassette('fixtures/vcr_cassettes/first_test.yaml'):
+        with vcr.use_cassette(os.path.join(BASE_DIR, 'fixtures', 'vcr_cassettes', 'first_test.yaml')):
             td.pages[0]['text'] = requests.get(td.pages[0]['url']).text
 
-        with vcr.use_cassette('fixtures/vcr_cassettes/second_test.yaml'):
+        with vcr.use_cassette(os.path.join(BASE_DIR, 'fixtures', 'vcr_cassettes', 'second_test.yaml')):
             td.pages[1]['text'] = requests.get(td.pages[1]['url']).text
 
     def test_url(self):
@@ -29,12 +34,6 @@ class TestScrape(unittest.TestCase):
         seek = Links(self.url)
         self.assertIsInstance(seek._soup, bs4.BeautifulSoup)
 
-    def test_find_bad_filter_param(self):
-        """ Bad filters parameter inputs """
-        seek = Links(self.url)
-        self.assertRaises(Exception, seek.find, filters=25)
-        self.assertRaises(Exception, seek.find, filters=['href', 'style'])
-
     def test_find_limit_param(self):
         """ How does find() handle the limit property """
         seek = Links(self.url)
@@ -83,5 +82,21 @@ class TestScrape(unittest.TestCase):
             for i, link in enumerate(actual_list):
                 self.assertDictEqual(link, page['limit_sort_href'][i])
 
+    def test_find_exclude(self):
+        """ Determine if excluding links removes the links """
+        for page in td.pages:
+            seek = Links(text=page['text'])
+            actual_list = seek.find(exclude=[{"class": re.compile("gb1")}])
+            self.assertEqual(len(actual_list), page['exclude_links'])
+            actual_list = seek.find(exclude=[{"class": "gb1"}])
+            self.assertEqual(len(actual_list), page['exclude_links'])
+
+    def test_find_duplicates(self):
+        """ Determine if removing duplicates works """
+        for page in td.pages:
+            seek = Links(text=page['text'])
+            actual_list = seek.find(duplicates=False)
+            self.assertEqual(len(actual_list), page['duplicate_links'])
+
 if __name__ == '__main__':
     unittest.main(verbosity=2)
